@@ -39,9 +39,9 @@ extern "C" {
 #endif /* __cplusplus */
 
 
-#define E_ICON_BAR_BG_ITEM(obj)          (GTK_CHECK_CAST((obj), e_icon_bar_bg_item_get_type (), EIconBarBgItem))
-#define E_ICON_BAR_BG_ITEM_CLASS(k)      (GTK_CHECK_CLASS_CAST ((k), e_icon_bar_bg_item_get_type (), EIconBarBgItemClass))
-#define E_IS_ICON_BAR_BG_ITEM(o)         (GTK_CHECK_TYPE((o), e_icon_bar_bg_item_get_type ()))
+#define E_ICON_BAR_BG_ITEM(obj)          (G_TYPE_CHECK_INSTANCE_CAST((obj), e_icon_bar_bg_item_get_type (), EIconBarBgItem))
+#define E_ICON_BAR_BG_ITEM_CLASS(k)      (G_TYPE_CHECK_CLASS_CAST ((k), e_icon_bar_bg_item_get_type (), EIconBarBgItemClass))
+#define E_IS_ICON_BAR_BG_ITEM(o)         (G_TYPE_CHECK_INSTANCE_TYPE((o), e_icon_bar_bg_item_get_type ()))
 
 
 typedef struct _EIconBarBgItem       EIconBarBgItem;
